leaftools.label_leaves_in_expr_with_melodic_chromatic_interval_classes
======================================================================

.. autofunction:: abjad.tools.leaftools.label_leaves_in_expr_with_melodic_chromatic_interval_classes.label_leaves_in_expr_with_melodic_chromatic_interval_classes
